@@ -1037,7 +1037,7 @@ def parallelize_preprocess(func, iterator, processes, progress_bar=False):
 # Map cleaned corpus token list (without punctuation) to original token list
 ############################################################################
 
-def map_cleaned_corpus(corpus, cleaned_corpus):
+def map_cleaned_corpus(corpus, cleaned_corpus,tokens_are_lowercase):
     mapping = []
     # list with cleaned corpus tokens that are yet to be mapped
     # ('token',index_original_corpus)
@@ -1050,12 +1050,17 @@ def map_cleaned_corpus(corpus, cleaned_corpus):
         if i > len(cleaned_corpus) - 1:
             cleaned_data_end = True
 
-        if cleaned_data_end is False and cleaned_corpus[i] == corpus[i]:
+        corpus_token = corpus[i]
+
+        if tokens_are_lowercase:
+            corpus_token = corpus[i].lower()
+
+        if cleaned_data_end is False and cleaned_corpus[i] == corpus_token:
             mapping.append(i)
 
         elif len(backlog) > 0:
             for pair in backlog:
-                if pair[0] == corpus[i]:
+                if pair[0] == corpus_token:
                     mapping[pair[1]] = i
                     backlog.remove(pair)
 
